@@ -21,12 +21,12 @@ function(mimm=NULL, x=mycor, data=d, fac.names=NULL,
 
          fun_call=NULL, ...) {
 
+
   # a dot in a parameter name to an underscore
   dots <- list(...)
   if (!is.null(dots)) if (length(dots) > 0) {
-    change <- c("min.cor", "min.res", "heat.map", "pdf.file")
     for (i in 1:length(dots)) {
-      if (names(dots)[i] %in% change) {
+      if (grepl(".", names(dots)[i], fixed=TRUE)) {
         nm <- gsub(".", "_", names(dots)[i], fixed=TRUE)
         assign(nm, dots[[i]])
         get(nm)
